==> haskell-data-memocombinators-0.5.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-memocombinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-memocombinators
version:              0.5.1
visibility:           public
id:                   data-memocombinators-0.5.1-J7EsR066eT1Hw3WzPPY2GN
key:                  data-memocombinators-0.5.1-J7EsR066eT1Hw3WzPPY2GN
license:              BSD-3-Clause
maintainer:           lrpalmer@gmail.com
author:               Luke Palmer
stability:            experimental
homepage:             http://github.com/luqui/data-memocombinators
synopsis:             Combinators for building memo tables.
description:          Combinators for building memo tables.
category:             Data
abi:                  0814f0d121fcb2bcd2cee1d110b08a50
exposed:              True
exposed-modules:      Data.MemoCombinators Data.MemoCombinators.Class
import-dirs:          /usr/lib/ghc-9.0.2/site-local/data-memocombinators-0.5.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/data-memocombinators-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-memocombinators
hs-libraries:         HSdata-memocombinators-0.5.1-J7EsR066eT1Hw3WzPPY2GN
depends:
    array-0.5.4.0 base-4.15.1.0
    data-inttrie-0.1.4-A8lNy6IOMjEDabPAIootTY

haddock-interfaces:
    /usr/share/doc/haskell-data-memocombinators/html/data-memocombinators.haddock

haddock-html:         /usr/share/doc/haskell-data-memocombinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-memocombinators-0.5.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-memocombinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-memocombinators
version:              0.5.1
visibility:           public
id:                   data-memocombinators-0.5.1-1ydzJrOTZVDHaJ1yRYWlmz
key:                  data-memocombinators-0.5.1-1ydzJrOTZVDHaJ1yRYWlmz
license:              BSD-3-Clause
maintainer:           lrpalmer@gmail.com
author:               Luke Palmer
stability:            experimental
homepage:             http://github.com/luqui/data-memocombinators
synopsis:             Combinators for building memo tables.
description:          Combinators for building memo tables.
category:             Data
abi:                  db67da7424dce969eed3bebe9589cf83
exposed:              True
exposed-modules:      Data.MemoCombinators Data.MemoCombinators.Class
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-memocombinators-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-memocombinators-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-memocombinators
hs-libraries:         HSdata-memocombinators-0.5.1-1ydzJrOTZVDHaJ1yRYWlmz
depends:
    array-0.5.4.0 base-4.16.4.0
    data-inttrie-0.1.4-1hAY90LQ90U2txAvTXCVsM

haddock-interfaces:
    /usr/share/doc/haskell-data-memocombinators/html/data-memocombinators.haddock

haddock-html:         /usr/share/doc/haskell-data-memocombinators/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
